@@ -167,6 +167,7 @@ gpm_manager_play (GpmManager *manager, GpmManagerSound action, gboolean force)
 	const gchar *id = NULL;
 	const gchar *desc = NULL;
 	gboolean ret;
+	gint retval;
 
 	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_UI_ENABLE_BEEPING, NULL);
 	if (!ret && !force) {
@@ -223,9 +224,11 @@ gpm_manager_play (GpmManager *manager, GpmManagerSound action, gboolean force)
 	}
 
 	/* play the sound, using sounds from the naming spec */
-	ca_context_play (ca_gtk_context_get (), 0,
-			 CA_PROP_EVENT_ID, id,
-			 CA_PROP_EVENT_DESCRIPTION, desc, NULL);
+	retval = ca_context_play (ca_gtk_context_get (), 0,
+				  CA_PROP_EVENT_ID, id,
+				  CA_PROP_EVENT_DESCRIPTION, desc, NULL);
+	if (retval < 0)
+		egg_warning ("failed to play %s: %s", id, ca_strerror (retval));
 	return TRUE;
 }
 
@@ -329,7 +332,7 @@ gpm_manager_blank_screen (GpmManager *manager, GError **noerror)
 {
 	gboolean do_lock;
 	gboolean ret = TRUE;
-	GError  *error = NULL;
+	GError *error = NULL;
 
 	do_lock = gpm_control_get_lock_policy (manager->priv->control,
 					       GPM_CONF_LOCK_ON_BLANK_SCREEN);
@@ -337,7 +340,7 @@ gpm_manager_blank_screen (GpmManager *manager, GError **noerror)
 		if (!gpm_screensaver_lock (manager->priv->screensaver))
 			egg_debug ("Could not lock screen via gnome-screensaver");
 	}
-	gpm_dpms_set_mode_enum (manager->priv->dpms, GPM_DPMS_MODE_OFF, &error);
+	gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_OFF, &error);
 	if (error) {
 		egg_debug ("Unable to set DPMS mode: %s", error->message);
 		g_error_free (error);
@@ -357,12 +360,11 @@ gpm_manager_blank_screen (GpmManager *manager, GError **noerror)
 static gboolean
 gpm_manager_unblank_screen (GpmManager *manager, GError **noerror)
 {
-	gboolean  do_lock;
-	gboolean  ret = TRUE;
-	GError   *error;
+	gboolean do_lock;
+	gboolean ret = TRUE;
+	GError *error = NULL;
 
-	error = NULL;
-	gpm_dpms_set_mode_enum (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
+	gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
 	if (error) {
 		egg_debug ("Unable to set DPMS mode: %s", error->message);
 		g_error_free (error);
@@ -704,7 +706,7 @@ idle_do_sleep (GpmManager *manager)
  * @mode: The idle mode, e.g. GPM_IDLE_MODE_BLANK
  * @manager: This class instance
  *
- * This callback is called when gnome-screensaver detects that the idle state
+ * This callback is called when the idle class detects that the idle state
  * has changed. GPM_IDLE_MODE_BLANK is when the session has become inactive,
  * and GPM_IDLE_MODE_SLEEP is where the session has become inactive, AND the
  * session timeout has elapsed for the idle action.
@@ -732,10 +734,10 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmManager *manager)
 		egg_debug ("Idle state changed: NORMAL");
 		gpm_brightness_kbd_undim (manager->priv->brightness_kbd);
 	} else if (mode == GPM_IDLE_MODE_BLANK) {
-		egg_debug ("Idle state changed: SESSION");
+		egg_debug ("Idle state changed: BLANK");
 		gpm_brightness_kbd_dim (manager->priv->brightness_kbd);
 	} else if (mode == GPM_IDLE_MODE_SLEEP) {
-		egg_debug ("Idle state changed: SYSTEM");
+		egg_debug ("Idle state changed: SLEEP");
 		if (gpm_manager_is_inhibit_valid (manager, FALSE, "timeout action") == FALSE)
 			return;
 		idle_do_sleep (manager);
@@ -810,7 +812,7 @@ static void
 update_dpms_throttle (GpmManager *manager)
 {
 	GpmDpmsMode mode;
-	gpm_dpms_get_mode_enum (manager->priv->dpms, &mode, NULL);
+	gpm_dpms_get_mode (manager->priv->dpms, &mode, NULL);
 
 	/* Throttle the manager when DPMS is active since we can't see it anyway */
 	if (mode == GPM_DPMS_MODE_ON) {
@@ -1057,7 +1059,9 @@ gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
 		return;
 
 	if (strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT) == 0 ||
-	    strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC) == 0)
+	    strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC) == 0 ||
+	    strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
+	    strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC) == 0)
 		gpm_manager_sync_policy_sleep (manager);
 
 	/* set keyboard brightness */
@@ -1125,7 +1129,7 @@ screensaver_auth_request_cb (GpmScreensaver *screensaver, gboolean auth_begin, G
 		/* We turn on the monitor unconditionally, as we may be using
 		 * a smartcard to authenticate and DPMS might still be on.
 		 * See #350291 for more details */
-		gpm_dpms_set_mode_enum (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
+		gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
 		if (error != NULL) {
 			egg_warning ("Failed to turn on DPMS: %s", error->message);
 			g_error_free (error);
@@ -1249,7 +1253,17 @@ gpm_engine_charge_low_cb (GpmEngine *engine, DkpObject *obj, GpmManager *manager
 	const gchar *title = NULL;
 	gchar *message = NULL;
 	gchar *remaining_text;
-	gchar *icon;
+	gchar *icon = NULL;
+	gboolean on_ac;
+
+	/* check to see if we are on AC */
+	if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
+		on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
+		if (on_ac) {
+			egg_warning ("ignoring low message as we are not on battery power");
+			goto out;
+		}
+	}
 
 	if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
 		title = _("Laptop battery low");
@@ -1282,6 +1296,7 @@ gpm_engine_charge_low_cb (GpmEngine *engine, DkpObject *obj, GpmManager *manager
 	icon = gpm_devicekit_get_object_icon (obj);
 	gpm_notify_display (manager->priv->notify, title, message, GPM_NOTIFY_TIMEOUT_LONG, icon, GPM_NOTIFY_URGENCY_NORMAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
+out:
 	g_free (icon);
 	g_free (message);
 }
@@ -1307,8 +1322,18 @@ gpm_engine_charge_critical_cb (GpmEngine *engine, DkpObject *obj, GpmManager *ma
 	gchar *action_text = NULL;
 	gchar *remaining_text;
 	gchar *action;
-	gchar *icon;
+	gchar *icon = NULL;
 	gchar *time_text;
+	gboolean on_ac;
+
+	/* check to see if we are on AC */
+	if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
+		on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
+		if (on_ac) {
+			egg_warning ("ignoring critically low message as we are not on battery power");
+			goto out;
+		}
+	}
 
 	if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
 		title = _("Laptop battery critically low");
@@ -1372,6 +1397,7 @@ gpm_engine_charge_critical_cb (GpmEngine *engine, DkpObject *obj, GpmManager *ma
 	icon = gpm_devicekit_get_object_icon (obj);
 	gpm_notify_display (manager->priv->notify, title, message, GPM_NOTIFY_TIMEOUT_LONG, icon, GPM_NOTIFY_URGENCY_CRITICAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
+out:
 	g_free (icon);
 	g_free (message);
 }
@@ -1385,8 +1411,17 @@ gpm_engine_charge_action_cb (GpmEngine *engine, DkpObject *obj, GpmManager *mana
 	const gchar *title = NULL;
 	gchar *action;
 	gchar *message = NULL;
-	gchar *icon;
+	gchar *icon = NULL;
+	gboolean on_ac;
 
+	/* check to see if we are on AC */
+	if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
+		on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
+		if (on_ac) {
+			egg_warning ("ignoring action signal as we are not on battery power");
+			goto out;
+		}
+	}
 	if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
 		title = _("Laptop battery critically low");
 
@@ -1453,6 +1488,7 @@ gpm_engine_charge_action_cb (GpmEngine *engine, DkpObject *obj, GpmManager *mana
 			    title, message, GPM_NOTIFY_TIMEOUT_LONG,
 			    icon, GPM_NOTIFY_URGENCY_CRITICAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
+out:
 	g_free (icon);
 	g_free (message);
 }
